  program

  include('aiMailMerge.inc'),once

!------------------------------------------------------------------------------
! Mailmerge by Lars Bevik, Aileron AB, Sweden. lars.bevik@aileron.se
! This code is using the aiMailmerge.dll.
!
! Here is how you use it:
!
!   1.  Create a Word document and put fields on it. The idea is to use fields
!       from a queue (in the example below it's the fields from the MMQue) and
!       then feed the Word template with values from the queue. In the Word
!       template file you insert mailmerge fields like this:
!
!       menu "Insert -> Field.
!
!       A form appears with 2 listboxes and an input field which contains the text "=".
!       Replace the "=" by, for example, the text "Mergefield CompanyName".
!
!   2.  Use the aiMailMergClass to create data to send to the dll.
!       Define a queue with records, one for each letter you want to send.
!       Use the field names of the queue as mailmerge field on the doc template.
!
! As you can see you have to define the fields, one at a time (AddField).
! The reason I am doing it this way is that I am defining the type of field
! used (string, real or integer). If all fields were strings I could have
! passed the queue and let the aiMailMerge extract both field names and
! field data. The code would have been much simpler.
!------------------------------------------------------------------------------
  map
    Test
  end

! A queue to hold mailmerge records. Even if you are filling in one
! form (one record) you have to create a queue with all the fields
! you want to put on the form.

MMQue           queue
CompanyName       string(50)
CustomerName      string(80)
Address           string(50)
ZipCode           string(6)
City              string(50)
Country           string(50)
EmployeeName      string(50)                            !Sorry, but we have to have this in every record
                end


  code
  Test

!------------------------------------------------------------------------------
Test procedure
!------------------------------------------------------------------------------
! Our test procedure

Window WINDOW('Testing XmlMailMerge.dll'),AT(,,140,53),FONT('MS Sans Serif',,,,CHARSET:ANSI),SYSTEM,GRAY
       BUTTON('Run!'),AT(44,16,45,14),USE(?Button1)
     END

mm              aiMailMergeClass                        !The mailmerge object

  code

  ! Add two records
  MMQue.CompanyName = 'Aileron AB'
  MMQue.CustomerName = 'Lasse Bevik'
  MMQue.Address = 'Rudbecksgatan 86'
  MMQue.ZipCode = '216 22'
  MMQue.City = 'Limhamn'
  MMQue.Country = 'Sweden'
  MMQue.EmployeeName = 'H.W. Ford'
  add(MMQue)

  ! The second records
  MMQue.CompanyName = 'Acme Corporation'
  MMQue.CustomerName = 'Hubert Humperdink'
  MMQue.Address = '1123 Ocean drive'
  MMQue.ZipCode = '12345'
  MMQue.City = 'Gotham City'
  MMQue.Country = 'America'
  MMQue.EmployeeName = 'H.W. Ford'
  add(MMQue)

  ! Create an xml string to be passed to the aiMailMerge.dll

  ! Create string buffer big enough to contain string data (including
  ! xml tags). Make it big enough. The receiving procedure can handle
  ! 128 kB
  mm.Init(4000)

  ! Set another window title and text. The default title is "MailMerge"
  ! and the default text is "Starting MS Word...". If you don't want
  ! to change these, you can skip these two lines.
  mm.WinTitle = 'My Mailmerge'
  mm.WinText = 'Working on it...'

  ! Initialize with template and encoding. It's ok to leave encoding blank.
  mm.BeginXML('C:\D5 MailMerge\Engelsk version\template.doc','ISO-8859-1')

  ! The first step is to Write field data. Only the fields you define
  ! here can be used in the doc file. The spelling has to be exactly
  ! the same here as thoose used in the queue.
  mm.BeginFields
  mm.AddField('CompanyName',ftString,30)
  mm.AddField('CustomerName',ftString,80)
  mm.AddField('Address',ftString,60)
  mm.AddField('ZipCode',ftString,6)
  mm.AddField('City',ftString,30)
  mm.AddField('Country',ftString,30)
  mm.AddField('EmployeeName',ftString,50)
  mm.EndFields

  ! The second step is to add records to be printed. Loop through
  ! the queue
  mm.BeginData
  loop i# = 1 to records(MMQue)
    get(MMQue,i#)
    mm.AddFieldsFromQue(MMQue)
  end
  mm.EndData

  ! End send string
  mm.EndXML
  open(Window)
  accept
    case accepted()
    of ?Button1
      ! Activate dll
      mm.Activate
    end
  end
  close(Window)
  mm.Kill

